
<a id="add_prn_form"
class="list-group-item list-group-item-success"
tabindex="0"
href="javascript://" data-toggle="popover" data-placement="auto" data-html="true" title="Add PRN {{ label|title }}" role="button"
data-content="
<div class='list-group'>
	{% if not prn_forms%}<small>There are no PRN {{ label }}s to add.</small>{% endif %}
{% for prn_form in prn_forms %}
<a id='show-link-to-add-{{ prn_form.model }}' class='list-group-item list-group-item-success'
title='click to add'
href='{{ prn_form.add_url }}?next={{ subject_dashboard_url }},appointment,subject_identifier&subject_identifier={{ subject_identifier }}&appointment={{ appointment_pk }}&{{ prn_form.visit_model_attr }}={{ prn_form.subject_visit }}&panel={{ prn_form.panel.pk }}'>
<span class='text text-default text-nowrap small'><i class='fas fa-plus fa-1x fa-fw' aria-hidden='true'></i> {{ prn_form.verbose_name }} {% if label == REQUISITION and not prn_form.panel.pk %}Invalid Panel!{% endif %}</span>
</a>
{% endfor %}
</div>
<p><a title='close' class='btn btn-sm btn-primary pull-right'><i class='fas fa-times fa-fw' aria-hidden='true'></i></a><br></p>">
<span class="text text-default" title="Click to see more ..."><i class="fas fa-caret-left" aria-hidden="true"></i> <small>Add PRN {{ label }}s</small></span>
</a>
